# dreamtim package

## Submodules

## dreamtim.calculator module

## dreamtim.statistical_tools module


### dreamtim.statistical_tools.assign_data(centroids: Sequence[Tuple[int, ...]], data: Iterable[Tuple[int, ...]])
Group the data points to the closest centroid


### dreamtim.statistical_tools.compute_centroids(groups: Iterable[Sequence[Tuple[int, ...]]])
Compute the centroid for each group


### dreamtim.statistical_tools.dist(p: typing.Tuple[int, ...], q: typing.Tuple[int, ...], fsum=<built-in function fsum>, sqrt=<built-in function sqrt>, zip=<class 'zip'>)
Euclidian distance for multidemensional data


### dreamtim.statistical_tools.k_means(data: Iterable[Tuple[int, ...]], k: int = 2, iterations: int = 50)

### dreamtim.statistical_tools.mean(data: Iterable[float])
Accurate arithemetic mean


### dreamtim.statistical_tools.transpose(data: Iterable[Iterable])
Swap the rows and columns in a 2-D array of data

## Module contents

This is the package with useful functions for personal usage
